.. _spkg_sagemath_pari_nflistdata:

==================================================================================
sagemath_pari_nflistdata: Computational Number Theory with PARI/GP: nflist data
==================================================================================


This pip-installable distribution ``passagemath-pari-nflistdata`` is a
distribution of data for use with ``passagemath-pari``.


What is included
----------------

- Wheels on PyPI include the nflistdata files


Type
----

optional


Dependencies
------------

- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pari_nflistdata`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`

Version Information
-------------------

package-version.txt::

    10.6.4

version_requirements.txt::

    passagemath-pari-nflistdata ~= 10.6.4.0

Equivalent System Packages
--------------------------

(none known)
